import { 
  select,
	csv,
  scaleLinear,
  scaleOrdinal,
  extent,
  axisBottom,
  axisLeft,
  line,
  scaleBand,
  max,
  min,
  scaleQuantize
} from 'd3';


const render = (data) => {
	const svg = select('svg');
  const width = +svg.attr('width');
  const height = +svg.attr('height');
  const xValue = d => d.time;
  const yValue = d => d.dif;
  const margin = {top: 90, bottom: 40, left: 90, right: 90};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const g = svg.append('g');
  
  const xScale = scaleBand()
  	.domain(data.map(xValue))
  	.range([0, innerWidth]);
  
  const yScale = scaleLinear()
  	.domain([min(data, yValue), max(data, yValue)])
  	.range([innerHeight, 0])
  	.nice();

  const xAxis = axisBottom(xScale);
  const yAxis = axisLeft(yScale);
  
  const xAxisG = g.append('g').call(xAxis);
  const yAxisG = g.append('g').call(yAxis);
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  
  xAxisG.attr('transform', `translate(0, ${innerHeight})`);
  
  console.log(lineGenerator(data));
  g.append('path')
	  .attr('d', lineGenerator(data))
  	.attr('fill', 'none')
  	.attr('stroke', 'black')
  	.attr('stroke-width', '5');
  
  g.attr('transform', `translate(${margin.left}, ${margin.top})`)
  
}

csv('overwatch.csv').then((data) => {
  data.map( (d) => d.dif = +d.dif);
  
	console.log(data);
  render(data);
})